// -*- C++ -*-
/*!
 * @file  CheckConnect.cpp
 * @brief Check connect sample component
 * $Date$
 *
 * $Id$
 */

#include "CheckConnect.h"


using namespace std;

// Module specification
static const char* checkconnect_spec[] =
  {
    "implementation_id", "CheckConnect",
    "type_name",         "CheckConnect",
    "description",       "Check connect sample component",
    "version",           "1.0",
    "vendor",            "S.K",
    "category",          "example",
    "activity_type",     "DataFlowComponent",
    "max_instance",      "10",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables

    ""
  };

CheckConnect::CheckConnect(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    m_refIn("ref", m_ref),
    m_velOut("vel", m_vel),
    dummy(0)
{
  // Registration: InPort/OutPort/Service
  // Set InPort buffers
  registerInPort("ref", m_refIn);
  
  // Set OutPort buffer
  registerOutPort("vel", m_velOut);
}


CheckConnect::~CheckConnect()
{
}


RTC::ReturnCode_t CheckConnect::onInitialize()
{
  return RTC::RTC_OK;
}



RTC::ReturnCode_t CheckConnect::onActivated(RTC::UniqueId ec_id)
{
  /*
   * $B$3$N%3%s%]!<%M%s%H$N%]!<%H$r<hF@!#(B
   */
  PortList_var plist_var;
  plist_var = get_ports();

  /* 
   * CORBA_SeqUtil::fine()$B$N0z?t$K(B_var$B7?(B($B$3$3$G$O!"(BPortList_var$B7?(B)
   * $B$rEO$9;v$,$G$-$J$$$?$a!"(BPortList$B$N0l;~%*%V%8%'%/%H$r:n@.$7$F$$$k!#(B
   */
  PortList plist(plist_var);


  /*
   * $B%$%s%]!<%H$,B>$N%]!<%H$H@\B3$5$l$F$$$k$+$r3NG'$7$?$$$?$a!"%$%s(B
   * $B%]!<%H%*%V%8%'%/%H$,(BPortList$B$N2?HVL\$K3JG<$5$l$F$$$k$+$rC5$9!#(B
   */
  CORBA::Long idx;
  idx = CORBA_SeqUtil::find(plist, find_port_name("ref"));

  /* $B%(%i!<%A%'%C%/(B */
  if (idx < 0) {
    cout << "Not found port name: ref" << endl;
    return RTC::RTC_ERROR;
  }


  /*
   * $B%$%s%]!<%H$,B>%]!<%H$H@\B3$5$l$k$^$G%k!<%W$9$k!#(B
   * connector_profiles$B$N%5%$%:$,(B1$B0J>e$G$"$l$P@\B3$5$l$F$$$k!#(B
   */
  bool connect_flag = false;
  while (!connect_flag) {
    if (plist_var[idx]->get_port_profile()->connector_profiles.length() > 0) {
      cout << "port connected." << endl;
      connect_flag = true;
    }
  }


  return RTC::RTC_OK;
}



extern "C"
{
 
  void CheckConnectInit(RTC::Manager* manager)
  {
    RTC::Properties profile(checkconnect_spec);
    manager->registerFactory(profile,
                             RTC::Create<CheckConnect>,
                             RTC::Delete<CheckConnect>);
  }
  
};


